@@ -1,45 +1,43 @@
-package Dancer::Logger::Capture;
-our $AUTHORITY = 'cpan:SUKRIA';
 # ABSTRACT: Capture dancer logs
-$Dancer::Logger::Capture::VERSION = '1.3522';
-use strict;
-use warnings;
-
-
-
-use base "Dancer::Logger::Abstract";
 
+package Dancer::Logger::Capture;
+{
+    $Dancer::Logger::Capture::VERSION = '2.0000_01';
+}
+use Moo;
 use Dancer::Logger::Capture::Trap;
-my $Trap = Dancer::Logger::Capture::Trap->new;
 
-sub _log {
-    my($self, $level, $message) = @_;
+with 'Dancer::Core::Role::Logger';
 
-    $Trap->store( $level => $message );
+
+has trapper => (
+    is      => 'ro',
+    lazy    => 1,
+    builder => '_build_trapper',
+);
+
+sub _build_trapper { Dancer::Logger::Capture::Trap->new }
+
+sub log {
+    my ($self, $level, $message) = @_;
+
+    $self->trapper->store($level => $message);
     return;
 }
 
-sub trap {
-    return $Trap;
-}
-
-
-
 1;
 
 __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Dancer::Logger::Capture - Capture dancer logs
 
 =head1 VERSION
 
-version 1.3522
+version 2.0000_01
 
 =head1 SYNOPSIS
 
@@ -48,21 +46,7 @@ version 1.3522
     my $trap = Dancer::Logger::Capture->trap;
     my $logs = $trap->read;
 
-=head1 DESCRIPTION
-
-This is a logger class for L<Dancer> which captures all logs to an object.
-
-Its primary purpose is for testing.
-
-=head2 Methods
-
-=head3 trap
-
-Returns the L<Dancer::Logger::Capture::Trap> object used to capture
-and read logs.
-
-=head1 EXAMPLE
-
+	#a real-world example
     use Test::More import => ['!pass'], tests => 2;
     use Dancer;
 
@@ -80,17 +64,32 @@ and read logs.
     # each call to read cleans the trap
     is_deeply $trap->read, [];
 
+=head1 DESCRIPTION
+
+This is a logger class for L<Dancer> which captures all logs to an object.
+
+It's primary purpose is for testing.
+
+=head1 METHODS
+
+=head2 trap
+
+Returns the L<Dancer::Logger::Capture::Trap> object used to capture
+and read logs.
+
 =head1 SEE ALSO
 
 L<Dancer::Logger>, L<Dancer::Logger::Capture::Trap>
 
+=cut
+
 =head1 AUTHOR
 
 Dancer Core Developers
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Alexis Sukrieh.
+This software is copyright (c) 2012 by Alexis Sukrieh.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
