@@ -1,52 +1,44 @@
-package Dancer::Logger::Capture::Trap;
-our $AUTHORITY = 'cpan:SUKRIA';
-$Dancer::Logger::Capture::Trap::VERSION = '1.3522';
 # ABSTRACT: a place to store captured Dancer logs
-use strict;
-use warnings;
-use base 'Dancer::Object';
 
-
-__PACKAGE__->attributes( "_storage" );
-
-sub init {
-    my $self = shift;
-    $self->_storage([]) unless $self->_storage;
+package Dancer::Logger::Capture::Trap;
+{
+    $Dancer::Logger::Capture::Trap::VERSION = '2.0000_01';
 }
+use Moo;
+use Dancer::Core::Types;
+
+has storage => (
+    is      => 'rw',
+    isa     => ArrayRef,
+    default => sub { [] },
+);
 
 sub store {
-    my($self, $level, $message) = @_;
-
-    push @{$self->_storage}, { level => $level, message => $message };
+    my ($self, $level, $message) = @_;
+    push @{$self->storage}, {level => $level, message => $message};
 }
 
-
-
 sub read {
     my $self = shift;
 
-    my $logs = $self->_storage;
-    $self->_storage([]);
+    my $logs = $self->storage;
+    $self->storage([]);
     return $logs;
 }
 
-
-
 1;
 
 __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Dancer::Logger::Capture::Trap - a place to store captured Dancer logs
 
 =head1 VERSION
 
-version 1.3522
+version 2.0000_01
 
 =head1 SYNOPSIS
 
@@ -91,7 +83,7 @@ Dancer Core Developers
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Alexis Sukrieh.
+This software is copyright (c) 2012 by Alexis Sukrieh.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
