@@ -1,23 +1,18 @@
+# ABSTRACT: Test::More note() logging engine for Dancer
+
 package Dancer::Logger::Note;
-our $AUTHORITY = 'cpan:SUKRIA';
-#ABSTRACT: Test::More note() logging engine for Dancer
-$Dancer::Logger::Note::VERSION = '1.3522';
-use strict;
-use warnings;
-use base 'Dancer::Logger::Abstract';
-
-sub init {
-    my $self = shift;
-    $self->SUPER::init(@_);
-    require Test::More;
+{
+    $Dancer::Logger::Note::VERSION = '2.0000_01';
 }
+use Moo;
+use Test::More;
+with 'Dancer::Core::Role::Logger';
 
-sub _log {
+
+sub log {
     my ($self, $level, $message) = @_;
 
-    Test::More::note(
-        $self->format_message( $level => $message )
-    );
+    Test::More::note($self->format_message($level => $message));
 }
 
 1;
@@ -26,17 +21,13 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Dancer::Logger::Note - Test::More note() logging engine for Dancer
 
 =head1 VERSION
 
-version 1.3522
-
-=head1 SYNOPSIS
+version 2.0000_01
 
 =head1 DESCRIPTION
 
@@ -50,12 +41,7 @@ harness. It will only be visible in the verbose TAP stream." -- Test::More.
 
 =head1 METHODS
 
-=head2 init
-
-This method is called when C<< ->new() >> is called. It just loads Test::More
-lazily.
-
-=head2 _log
+=head2 log
 
 Use Test::More's note() to output the log message.
 
@@ -65,7 +51,7 @@ Dancer Core Developers
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Alexis Sukrieh.
+This software is copyright (c) 2012 by Alexis Sukrieh.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
