@@ -1,12 +1,14 @@
-package Dancer::Logger::Null;
-our $AUTHORITY = 'cpan:SUKRIA';
-#ABSTRACT: blackhole-like silent logging engine for Dancer
-$Dancer::Logger::Null::VERSION = '1.3520';
-use strict;
-use warnings;
-use base 'Dancer::Logger::Abstract';
+# ABSTRACT: Blackhole-like silent logging engine for Dancer
 
-sub _log {1}
+package Dancer::Logger::Null;
+{
+    $Dancer::Logger::Null::VERSION = '2.0000_01';
+}
+use Moo;
+with 'Dancer::Core::Role::Logger';
+
+
+sub log {1}
 
 1;
 
@@ -14,17 +16,13 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
-Dancer::Logger::Null - blackhole-like silent logging engine for Dancer
+Dancer::Logger::Null - Blackhole-like silent logging engine for Dancer
 
 =head1 VERSION
 
-version 1.3520
-
-=head1 SYNOPSIS
+version 2.0000_01
 
 =head1 DESCRIPTION
 
@@ -33,7 +31,7 @@ the log messages instead of displaying them anywhere.
 
 =head1 METHODS
 
-=head2 _log
+=head2 log
 
 Discards the message.
 
@@ -43,7 +41,7 @@ Dancer Core Developers
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Alexis Sukrieh.
+This software is copyright (c) 2012 by Alexis Sukrieh.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
