@@ -1,28 +1,47 @@
 package Dancer::ModuleLoader;
-our $AUTHORITY = 'cpan:SUKRIA';
-#ABSTRACT: dynamic module loading helpers for Dancer core components
-$Dancer::ModuleLoader::VERSION = '1.3522';
-# Abstraction layer for dynamic module loading
+{
+    $Dancer::ModuleLoader::VERSION = '2.0000_01';
+}
+
+# ABSTRACT: Dynamic module loading helpers for Dancer core components
 
 use strict;
 use warnings;
-use Module::Runtime qw/ use_module /;
+
 
 sub load {
     my ($class, $module, $version) = @_;
 
-    my ($res, $error) = $class->require($module, $version);
+    # 0 is a valid version, so testing trueness of $version is not enough
+    if (defined $version && length $version) {
+        my ($res, $error) = $class->load_with_params($module);
+        $res or return wantarray ? (0, $error) : 0;
+        local $@;
+        eval { $module->VERSION($version) };
+        $error = $@;
+        $error and return wantarray ? (0, $error) : 0;
+        return 1;
+    }
+
+    # normal 'use', can be done via require + import
+    my ($res, $error) = $class->load_with_params($module);
     return wantarray ? ($res, $error) : $res;
 }
 
+
 sub require {
-    my ($class, $module, $version) = @_;
-    eval { defined $version ? use_module( $module, $version ) 
-                            : use_module( $module ) } 
-        or return wantarray ? (0, $@) : 0;
-    return 1; #success
+    my ($class, $module) = @_;
+    local $@;
+    my $module_filename = $module;
+    $module_filename =~ s!::|'!/!g;
+    $module_filename .= '.pm';
+    eval { require $module_filename };
+    my $error = $@;
+    $error and return wantarray ? (0, $error) : 0;
+    return 1;
 }
 
+
 sub load_with_params {
     my ($class, $module, @args) = @_;
     my ($res, $error) = $class->require($module);
@@ -42,6 +61,7 @@ sub load_with_params {
     return 1;
 }
 
+
 sub use_lib {
     my ($class, @args) = @_;
     use lib;
@@ -52,40 +72,19 @@ sub use_lib {
     return 1;
 }
 
-sub class_from_setting {
-    my ($self, $namespace, $setting) = @_;
-
-    my $class = '';
-    for my $token (split /_/, $setting) {
-        $class .= ucfirst($token);
-    }
-    return "${namespace}::${class}";
-}
-
 1;
 
 __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
-Dancer::ModuleLoader - dynamic module loading helpers for Dancer core components
+Dancer::ModuleLoader - Dynamic module loading helpers for Dancer core components
 
 =head1 VERSION
 
-version 1.3522
-
-=head1 SYNOPSIS
-
-Taken directly from Dancer::Template::TemplateToolkit (which is core):
-
-    die "Template is needed by Dancer::Template::TemplateToolkit"
-      unless Dancer::ModuleLoader->load('Template');
-
-    # we now have Template loaded
+version 2.0000_01
 
 =head1 DESCRIPTION
 
@@ -93,8 +92,7 @@ Sometimes in Dancer core we need to use modules, but we don't want to declare
 them all in advance in compile-time. These could be because the specific modules
 provide extra features which depend on code that isn't (and shouldn't) be in
 core, or perhaps because we only want these components loaded in lazy style,
-saving loading time a bit. For example, why load L<Template> (which isn't
-required by L<Dancer>) when you don't use L<Dancer::Template::TemplateToolkit>?
+saving loading time a bit.
 
 To do such things takes a bit of code for localizing C<$@> and C<eval>ing. That
 code has been refactored into this module to help Dancer core developers.
@@ -103,11 +101,13 @@ B<Please only use this for Dancer core modules>. If you're writing an external
 Dancer module (L<Dancer::Template::Tiny>, L<Dancer::Session::Cookie>, etc.),
 please simply "C<use ModuleYouNeed>" in your code and don't use this module.
 
-=head1 METHODS/SUBROUTINES
+WARNING, all the following methods are CLASS methods.
+
+=head1 METHODS
 
 =head2 load
 
-Runs something like "C<use ModuleYouNeed>" at runtime.
+Runs a "C<use ModuleYouNeed>".
 
     use Dancer::ModuleLoader;
     ...
@@ -127,7 +127,7 @@ Takes in arguments the module name, and optionally the minimum version number re
 In scalar context, returns 1 if successful, 0 if not.
 In list context, returns 1 if successful, C<(0, "error message")> if not.
 
-If you need to give argument to the loading module, please use the method C<load_with_params>
+If you need to give argumentto the loading module, please use the method C<load_with_params>
 
 =head2 require
 
@@ -154,11 +154,11 @@ Runs a "C<use ModuleYouNeed qw(param1 param2 ...)>".
 
     use Dancer::ModuleLoader;
     ...
-    Dancer::ModuleLoader->load_with_params('Something', qw(param1 param2) )
-        or die "Couldn't load Something with param1 and param2\n";
+    Dancer::ModuleLoader->load('Something', qw(param1 param2) )
+        or die "Couldn't load Something\n";
 
-    my ($res, $error) = Dancer::ModuleLoader->load_with_params('Something', @params);
-    $res or die "Couldn't load Something with @params: '$error'\n";
+    my ($res, $error) = Dancer::ModuleLoader->load('Something', @params);
+    $res or die "Couldn't load Something : '$error'\n";
 
 Takes in arguments the module name, and optionally parameters to pass to the import internal method.
 
@@ -184,45 +184,13 @@ can be generated and dynamic.
 In scalar context, returns 1 if successful, 0 if not.
 In list context, returns 1 if successful, C<(0, "error message")> if not.
 
-=head2 class_from_setting
-
-Given a setting in Dancer::Config, composes the class it should be.
-
-This is the function that translates:
-
-    # in config.yaml
-    template: "template_toolkit"
-
-To the class:
-
-    Dancer::Template::TemplateToolkit
-
-Example:
-
-    use Dancer::ModuleLoader;
-    my $class = Dancer::ModuleLoader->class_from_setting(
-        'Dancer::Template' => 'template_toolkit',
-    );
-
-    # $class == 'Dancer::Template::TemplateToolkit
-
-    $class = Dancer::ModuleLoader->class_from_setting(
-        'Dancer::Template' => 'tiny',
-    );
-
-    # class == 'Dancer::Template::Tiny
-
-=head1 SEE ALSO
-
-L<Module::Load>, L<Module::New::Loader>
-
 =head1 AUTHOR
 
 Dancer Core Developers
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Alexis Sukrieh.
+This software is copyright (c) 2012 by Alexis Sukrieh.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
