@@ -1,32 +1,42 @@
+#ABSTRACT: Pure Perl 5 template engine for Dancer
+
 package Dancer::Template::Simple;
-our $AUTHORITY = 'cpan:SUKRIA';
-#ABSTRACT: pure Perl 5 template engine for Dancer
-$Dancer::Template::Simple::VERSION = '1.3522';
+{
+    $Dancer::Template::Simple::VERSION = '2.0000_01';
+}
 use strict;
 use warnings;
 use Carp;
 
-use base 'Dancer::Template::Abstract';
-Dancer::Template::Simple->attributes('start_tag', 'stop_tag');
+use Moo;
 use Dancer::FileUtils 'read_file_content';
-use Dancer::Exception qw(:all);
 
-sub init {
+with 'Dancer::Core::Role::Template';
+
+
+has start_tag => (
+    is      => 'rw',
+    default => sub {'<%'},
+);
+
+has stop_tag => (
+    is      => 'rw',
+    default => sub {'%>'},
+);
+
+sub BUILD {
     my $self     = shift;
     my $settings = $self->config;
 
-    my $start = $settings->{'start_tag'} || '<%';
-    my $stop  = $settings->{'stop_tag'}  || '%>';
-
-    $self->start_tag($start) unless defined $self->start_tag;
-    $self->stop_tag($stop)   unless defined $self->stop_tag;
+    $settings->{$_} and $self->$_($settings->{$_})
+      for qw/ start_tag stop_tag /;
 }
 
 sub render {
     my ($self, $template, $tokens) = @_;
     my $content;
 
-    $content = _read_content_from_template($template);
+    $content = read_file_content($template);
     $content = $self->parse_branches($content, $tokens);
 
     return $content;
@@ -100,24 +110,6 @@ sub parse_branches {
     return join "", @buffer;
 }
 
-# private
-
-sub _read_content_from_template {
-    my ($template) = @_;
-    my $content = undef;
-
-    if (ref($template)) {
-        $content = $$template;
-    }
-    else {
-        raise core_template => "'$template' is not a regular file"
-          unless -f $template;
-        $content = read_file_content($template);
-        raise core_template => "unable to read content for file $template"
-          if not defined $content;
-    }
-    return $content;
-}
 
 sub _find_value_from_token_name {
     my ($key, $tokens) = @_;
@@ -161,19 +153,17 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
-Dancer::Template::Simple - pure Perl 5 template engine for Dancer
+Dancer::Template::Simple - Pure Perl 5 template engine for Dancer
 
 =head1 VERSION
 
-version 1.3522
+version 2.0000_01
 
 =head1 DESCRIPTION
 
-This template engine is provided as a default one for the L<< Dancer >> micro
+This template engine is provided as a default one for the Dancer micro
 framework.
 
 This template engine should be fine for development purposes but is not a
@@ -181,7 +171,7 @@ powerful one, it's written in pure Perl and has no C bindings to accelerate the
 template processing.
 
 If you want to power an application with Dancer in production environment, it's
-strongly advised to switch to L<< Dancer::Template::TemplateToolkit >>.
+strongly advised to switch to Dancer::Template::TemplateToolkit.
 
 =head1 SYNTAX
 
@@ -206,20 +196,11 @@ L<Dancer>, L<Dancer::Template>
 
 =head1 AUTHOR
 
-This module has been written by Alexis Sukrieh.
-
-=head1 LICENSE
-
-This module is free software and is released under the same terms as Perl
-itself.
-
-=head1 AUTHOR
-
 Dancer Core Developers
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Alexis Sukrieh.
+This software is copyright (c) 2012 by Alexis Sukrieh.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
